.. Coil CMS documentation master file, created by
   sphinx-quickstart on Sat Jan 10 17:53:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Coil demo site
==============

The Coil demo site is available at https://coildemo-site.getnikola.com/ and https://coildemo-admin.getnikola.com/ (user: demo, password: demo).

Coil CMS
========

.. toctree::
   :maxdepth: 3
   :glob:
   :numbered:

   user/index
   admin/index

Appendices
----------

.. toctree::
   :maxdepth: 2

   CHANGELOG
   LICENSE


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

